Blood of Wallachia

## Catchy tag line

Here we add an inspiring piece of text. Usually from H. P. Lovecraft
- Author, book

X is a fan created campaign for Arkham Horror: The Card Game for 1-4 players. X contains 8 scenarios (list scenarios).

## Contents

## Rules for the campaign specifically

Something about these rules

## Additional Rules and Clarifications

### Day, Night and the Calendar

You should totally play during the day or the night, and use a calendar to plan game nights.

Look, a lit of things!

- Do you prefer to have a good chance at winning a campaign the first time you play it?
- Is Arkham Horror more about the gameplay than the narrative?
- Does it feel cheap if the campaign changes core expectations, like “gathering clues leads to winning”, without telling you?
- Do you find that Arkham Horror is usually a hard game, that you rarely win?

If you answered “no” to all of these, you’re probably good to go. Otherwise, we’ll see you back here in 3 minutes.

### Templating language and Traits

A couple of new template choices is being used throughout Blood of Wallachia, both to use a more natural language and to spend less card space on easily understood game mechanics.

##### “Test X to...”

The very common template "Test <skill> (<difficulty<). If you succeed..." now has a short hand version.
"Test w(3). If you're successful, evade this enemy" could now be written as "Test w(3) to evade this enemy.". They are functionally identical.

## Expansion Icon

The cards in the X campaign expansion can be identified by this symbol before each cards’s collector number:

## Campaign Setup

To set up theX campaign, perform the following steps in order.

1. Choose investigator(s).
2. Each player assembles his or her investigator deck.
3. Choose difficulty level.
4. Assemble the campaign chaos bag.
5. Regardless of difficulty level:
   +1, 0, 0, -1, -1, -2, -2, -3, -4, S, S, S, T, E.

You're ready to begin at the Prologue.

# Prologue

Intro story part

More story.

If you playing on Hard or Expert continue to Prologue 1, otherwise skip to Prologue 2.

Prologue 1: Due to maintainance the train is delayed. You won’t be able to leave for another 2 days.

Cross of 2 days in the calendar in the campaign log. (4 marks)

Continue to Prologue 2.

Prologue 2: The rhythmic clatter

More story

The investigators must decide (choose one):

- Do the thing Proceed to Prologue 3.

- Do not do the thing Proceed to Prologue 4.

Prologue 3: You did the thing!

You start next scenario with 1 fewer resources. Add C to the chaos bag. Skip to Prologue 5.

Prologue 4: You didn't do the thing!

Add A to the chaos bag. Proceed to Prologue 5.

Prologue 5: Continue, please.

More story

Proceed to Scenario I

# Scenario I: Shadows in the Village

Story stuff

More story stuff

#### Setup

- Gather the Shadows in the Village encounter set. This set is indicated by the following icons:
- Find Carmilla in the Characters encounter set, and the entire Bats encounter set, and set them aside out of play. These sets are indicated by the following icons:
- Put each location into play. Each investigator start at either the Raven Hotel or the Village Square, but at least 1 investigator must start at the Village Square.
- Set the following cards aside, out of play: Concierge Stephania, Nurse Nikita.
- Split the rest of the encounter cards into Day and Night decks, and shuffle each deck.
- Checklist: 9 cards set aside out of play. 14 locations in play. 3 locations not connected to the rest. Investigators at the town square and possibly the hotel. 25 cards in Night Encounter Deck. 25 cards in Day Encounter Deck.

You are now ready to begin.

## # Codex 1: The Church

If it’s day:

The inside of the church looks more like a refuge than a house of worship. There’s sleeping bags on the floor and small tents and makeshift wall. Near the main doors are heavy fortifications. Looks like whoever has been camping here are afraid of visitors.

Any investigator may read this entry again while at the Church during night.

If it’s night:

A bunch of people are camping in here. They’ve brought sleeping bags, small tents and makeshift privacy walls made out of blankts. The main doors have been heavily fortified by wooden bars and a couple of book shelves. Looks like visitors are not welcome.

The priest show you how to get here unseen if you ever need a safe place to hide. Reveal the South Tunnel if it’s unrevealed.

## # Codex 2: Hospital

An nurse mentions an increase in injuries lately. People showing up with bruises, fractured bones, burn marks. Maybe he knows more than he’s letting on?

Put the set aside Nikita asset into play at The Hospital.

## # Codex 3: The Ionescus

After some convincing that you are indeed trying to help, Marta and Jonas Ionescus tells you a about their daughters disappearance. They also show you an entrance to the secret tunnels under the village, in case you need a way to travel the village at night.

Revel the North Tunnel if it’s unrevealed.

## # Codex 4: North Tunnel

After some searching, you find exits to the village.

The North Tunnel is connected to Ionescu’s Home and Raven Hotel until the end of the game.

## #Codex 5: Central Tunnel

After some searching, you find exits to the village.

The Center Tunnel is connected to Town Square until the end of the game.

## #Codex 6: South Tunnel

After some searching, you find exits to the village.

The South Tunnel is connected to Post Office and Church until the end of the game.

## #Codex 7: The Raven Hotel

You spend some time talking to the staff, asking around. Especially the Conceierge, Stephania opens op to you. It turns out that she haven’t lived here long enough to take on the almost paranoid nature that most of the townspeople seem to share. “People are just afraid. The nights are terrifying out here. Even more so during the cold and dark seasons. And lately, these hooded figures have been seen roaming around. Anyway, let me know if I can help you with anything. I highly suggest you get a map of the town if you haven’t been here before.”

Put the set aside Stephania asset into play at Raven Hotel.

## #Codex 8: Nikita

Nikita tells you about how nightly attacks occur in the village. Every day more people goes missing.

Add Nikita to the victory display.

## DO NOT READ
until end of scenario

If no resolution was reached (each investigator resignedor was defeated): On the other side of the dome entrance, youlook through the gossamer barrier to the ocean floor. The oceanreclaimed the alien dome in mere seconds. It is a minor miraclethat you weren’t swept away.

- Your failure has distracted you from your goals. Each investigator must erase 1 progress under their Task, if able.
- Skip to Resolution 3.

Resolution 1: The strange node pulses in your hand, projecting a soft bubble of light that repels the falling debris. You make it to the entrance as the dome bursts like a bubble. The expedition looks on in a mixture of awe and fear as torrent of seawater reclaims the alien structure. A small prick of pain shoots through your palm, and you look down to see the node bury itself in your palm, sending spidery black hairs radiating out under your skin. They retract painlessly when you pull the node away. Tillinghast will certainly be pleased with this find.

- Æ In the “Artifacts Earned” section of your Campaign Log, check the box next to “Barrier Node.”
- Æ Skip to Resolution 3.

Resolution 2: The reactivated core makes quick work of the flooded dome, draining the water in mere minutes. You survey the perimeter of the sunken ruin with the expedition, marveling at its ancient grandeur. The feeling of walking on a dry ocean floor, with fish flitting beyond the flickering bubble, is like something out of a dream. After several hours, the expedition presses on.

- Æ In your Campaign Log, record the power was diverted.
- Æ Each investigator earns 2 bonus experience from studying the Drowned Quarter at length.
- Æ Proceed to Resolution 3.

Resolution 3: The energy field protecting the tunnel back to the city continues to hold strong. The jagged foundations of R’lyeh continue to break off in pieces as the city rises. It is time to move on.

- Æ In your Campaign Log, cross out “The Drowned Quarter” on the R’lyeh map.
- Æ Each investigator earns experience equal to the victory X value of each card in the victory display.
- Æ Check your Campaign Log.
  - = If the expedition headed west, proceed to The Apiary (page 19).
  - = If the expedition headed east, proceed to The Western Wall (page 12)

# Interlude I – Rescue party

It’s clear by now that the cult is indeed behind the kidnappings. However, much is yet shrouded in mystery. You can only hope that you can decrypt what little evidence you have collected, and connected the dots between the wispered rumors you’ve heard.

Read the following rules regarding the next scenarios. After each scenario, you’ll be instructed to return here.

### Location and Cult leaders

For the next couple of scenarios, you’ll be asked about which locations you know about, which Cult Leader is present, when the ritual at a given location takes place, and if the ritual has already taken place.

You can only travel to locations (scenarios) you know about. It’s quite possible that you run out of locations to investigate before you’ve completed your task. Once have no more locations to visit, continue to Interlude 3.

Once you visit a location you might get asked when the ritual takes place. If you don’t know, you randomize it among the moon phases not yet known. You can use the included Moon Phase cards for this purpose. Each moon phase can only be associated with 1 location.

As for Cult Leaders, each Cult Leader can only be associated with 1 location. If you don’t know which Cult Leader is present on a location, randomize one of the available Leaders.

### Difficulty

When you gain enough leads you get a fix on the who and where a part of the ritual will happen. However, then “when” is determined by the difficulty you play on. When you draw cards from the cult leader or location deck, assign them according to the following:

Easy:

Always assign the cult leader and location to the next available moon phase that hasn’t happened yet.

Standard:

Assign cult leaders and locations to the next available moon phase, in order from first to last.

Hard/Expert:

When assigning locations and cult leaders, assign them to a random slot. You can use the included Moon Phase cards to randomize a slot.

# Scenario: The Lost Woods

You’ve found the area of the woods hinted by your investigation. As you enter the woods, you realize that the woods are incredible dense and foggy. It’s going to be very easy to get lost in there. Better be careful.

#### Setup

- Gather the The Lost Woods encounter set. This set is indicated by the following icon:
- Find Carmilla in the Characters encounter set, and the entire Bats encounter set, and set them aside out of play. These sets are indicated by the following icons:
- Put each location into play. Each investigator start at either the Raven Hotel or the Village Square, but at least 1 investigator must start at the Village Square.
- Set the following cards aside, out of play: Concierge Stephania, Nurse Nikita.
- Split the rest of the encounter cards into Day and Night decks, and shuffle each deck.
- Checklist: 9 cards set aside out of play. 14 locations in play. 3 locations not connected to the rest. Investigators at the town square and possibly the hotel. 25 cards in Night Encounter Deck. 25 cards in Day Encounter Deck.

You are now ready to begin.